@@ -17,7 +17,8 @@ AWS_SECRET_ACCESS_KEY = 'RXGzABW5FYfVx4IfxajGvZNmyJCfTtE2j+GX/AIk'
 # Postgres settings
 PG_DIR = '/var/lib/postgresql/9.1/main'
 RECOVERY_FILENAME = '%s/recovery.conf' % PG_DIR
-RECOVERY_TEMPLATE = '/etc/postgresql/9.1/main/recovery_template.conf'
+RECOVERY_TEMPLATE_SLAVE = '/etc/postgresql/9.1/main/recovery_template_slave.conf'
+RECOVERY_TEMPLATE_MASTER = '/etc/postgresql/9.1/main/recovery_template_master.conf'
 PG_CTL = '/usr/lib/postgresql/9.1/bin/pg_ctl'
 PG_USER = 'postgres'
 PG_TIMEOUT = 20  # Time to wait when attempting to connect to postgres
